@@ -17,13 +17,8 @@ class RoyaltyPolicyLAPClient:
                 break
         if not contract_address:
             raise ValueError(f"Contract address for RoyaltyPolicyLAP not found in config.json")
-        abi_path = os.path.join(os.path.dirname(__file__), 'RoyaltyPolicyLAP.json')
+        abi_path = os.path.join(os.path.dirname(__file__), '..', '..', 'abi', 'jsons', 'RoyaltyPolicyLAP.json')
         with open(abi_path, 'r') as abi_file:
             abi = json.load(abi_file)
         self.contract = self.web3.eth.contract(address=contract_address, abi=abi)
-    
-    def getRoyaltyData(self, ipId):
-        
-        return self.contract.functions.getRoyaltyData(ipId).call()
-        
     
\ No newline at end of file
